@@ -14,9 +14,23 @@ hookimpl = pluggy.HookimplMarker("tox")
 @hookimpl
 def tox_configure(config):
     # type: (Config) -> None
+    verbosity1("running tox-gh-actions")
+    if not is_running_on_actions():
+        verbosity1(
+            "tox-gh-actions won't override envlist "
+            "because tox is not running in GitHub Actions"
+        )
+        return
+    elif is_env_specified(config):
+        verbosity1(
+            "tox-gh-actions won't override envlist because "
+            "envlist is explicitly given via TOXENV or -e option"
+        )
+        return
+
     verbosity2("original envconfigs: {}".format(list(config.envconfigs.keys())))
-    verbosity2("original envlist: {}".format(config.envlist))
     verbosity2("original envlist_default: {}".format(config.envlist_default))
+    verbosity2("original envlist: {}".format(config.envlist))
 
     version = get_python_version()
     verbosity2("Python version: {}".format(version))
@@ -25,19 +39,11 @@ def tox_configure(config):
     verbosity2("tox-gh-actions config: {}".format(gh_actions_config))
 
     factors = get_factors(gh_actions_config, version)
+    verbosity2("using the following factors to decide envlist: {}".format(factors))
+
     envlist = get_envlist_from_factors(config.envlist, factors)
-    verbosity2("new envlist: {}".format(envlist))
-
-    if not is_running_on_actions():
-        verbosity1("tox is not running in GitHub Actions")
-        verbosity1("tox-gh-actions won't override envlist")
-        return
-    elif is_env_specified(config):
-        verbosity1("envlist is explicitly given via TOXENV or -e option")
-        verbosity1("tox-gh-actions won't override envlist")
-        return
-
     config.envlist_default = config.envlist = envlist
+    verbosity1("overriding envlist with: {}".format(envlist))
 
 
 @hookimpl
@@ -107,7 +113,7 @@ def get_python_version():
     if "PyPy" in sys.version:
         return "pypy" + str(sys.version_info[0])
     # Assuming running on CPython
-    return '.'.join([str(i) for i in sys.version_info[:2]])
+    return ".".join([str(i) for i in sys.version_info[:2]])
 
 
 def is_running_on_actions():
@@ -135,6 +141,7 @@ def is_env_specified(config):
 # which is licensed under MIT LICENSE
 # https://github.com/tox-dev/tox-travis/blob/0.12/LICENSE
 
+
 def parse_dict(value):
     # type: (str) -> Dict[str, str]
     """Parse a dict value from the tox config.
@@ -151,5 +158,5 @@ def parse_dict(value):
         }
     """
     lines = [line.strip() for line in value.strip().splitlines()]
-    pairs = [line.split(':', 1) for line in lines if line]
+    pairs = [line.split(":", 1) for line in lines if line]
     return dict((k.strip(), v.strip()) for k, v in pairs)
